#!/usr/bin/env node
'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _promise = require('babel-runtime/core-js/promise');

var _promise2 = _interopRequireDefault(_promise);

var _stringify = require('babel-runtime/core-js/json/stringify');

var _stringify2 = _interopRequireDefault(_stringify);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var handleAuthRequest = function () {
  var _ref2 = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee2(ctx) {
    var userId, blacklisted, response;
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            userId = ctx.request.body.user_id;
            _context2.next = 3;
            return isUserBlacklisted(userId);

          case 3:
            blacklisted = _context2.sent;
            response = {
              blacklisted: blacklisted
            };

            if (blacklisted) {
              ctx.status = 401;
            }
            logger.info('request from %s for user %s --> blacklisted %s', ctx.request.ip, userId, blacklisted, {
              userId: userId,
              ip: ctx.request.ip,
              port: ctx.request.headers['bukkit-server-port'],
              blacklisted: blacklisted
            });
            ctx.set('Content-Type', 'application/json');
            ctx.body = (0, _stringify2.default)(response);

          case 9:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this);
  }));

  return function handleAuthRequest(_x3) {
    return _ref2.apply(this, arguments);
  };
}();

var readFileAsync = function () {
  var _ref3 = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee3(file) {
    return _regenerator2.default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.next = 2;
            return new _promise2.default(function (resolve) {
              (0, _fs.readFile)(file, 'utf8', function (err, data) {
                resolve(data);
              });
            });

          case 2:
            return _context3.abrupt('return', _context3.sent);

          case 3:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, this);
  }));

  return function readFileAsync(_x4) {
    return _ref3.apply(this, arguments);
  };
}();

var isUserBlacklisted = function () {
  var _ref4 = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee4(userId) {
    var bannedUsersFile, bannedUsers;
    return _regenerator2.default.wrap(function _callee4$(_context4) {
      while (1) {
        switch (_context4.prev = _context4.next) {
          case 0:
            _context4.next = 2;
            return readFileAsync(process.env.BLACKLISTED_USERS_FILE || __dirname + '/banned_users.txt');

          case 2:
            bannedUsersFile = _context4.sent;

            if (bannedUsersFile) {
              _context4.next = 5;
              break;
            }

            return _context4.abrupt('return', false);

          case 5:
            bannedUsers = bannedUsersFile.toString().split('\n');
            return _context4.abrupt('return', bannedUsers.indexOf(userId) !== -1);

          case 7:
          case 'end':
            return _context4.stop();
        }
      }
    }, _callee4, this);
  }));

  return function isUserBlacklisted(_x5) {
    return _ref4.apply(this, arguments);
  };
}();

var _koa = require('koa');

var _koa2 = _interopRequireDefault(_koa);

var _koaRouter = require('koa-router');

var _koaRouter2 = _interopRequireDefault(_koaRouter);

var _koaBodyparser = require('koa-bodyparser');

var _koaBodyparser2 = _interopRequireDefault(_koaBodyparser);

var _fs = require('fs');

var _winston = require('winston');

var winston = _interopRequireWildcard(_winston);

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var app = new _koa2.default();
app.proxy = process.env.PROXY || false;

var router = new _koaRouter2.default();

var logger = new winston.Logger();
logger.add(winston.transports.File, {
  filename: process.env.LOG_FILE || __dirname + '/request.log',
  maxFiles: 5,
  maxsize: 5000000,
  tailable: true,
  json: process.env.JSON_LOG || true
});
logger.add(winston.transports.Console);

router.post('/', function () {
  var _ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee(ctx, next) {
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            if (!(!ctx.request.body || !ctx.request.body.user_id)) {
              _context.next = 2;
              break;
            }

            return _context.abrupt('return', ctx.status = 400);

          case 2:
            _context.next = 4;
            return handleAuthRequest(ctx);

          case 4:

            next();

          case 5:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, undefined);
  }));

  return function (_x, _x2) {
    return _ref.apply(this, arguments);
  };
}());

app.use((0, _koaBodyparser2.default)());
app.use(router.routes());
app.use(router.allowedMethods());

var server = app.listen(process.env.PORT || 3000, function () {
  logger.info('Spigot Anti Piracy Backend listening at http://%s:%s', server.address().address, server.address().port);
  logger.info('Logging to %s', process.env.LOG_FILE || __dirname + '/request.log');
  logger.info('Using %s for blacklisted users', process.env.BLACKLISTED_USERS_FILE || __dirname + '/banned_users.txt');
});

exports.default = app;